@@ -1,15 +1,11 @@
 /*
-** Copyright 1998 - 1999 Double Precision, Inc.
+** Copyright 1998 - 2007 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
 /*
-** $Id: cgihttpscriptptr.c,v 1.4 2003/07/07 15:19:13 mrsam Exp $
+** $Id: cgihttpscriptptr.c,v 1.5 2007/02/24 19:02:59 mrsam Exp $
 */
-#if	HAVE_CONFIG_H
-#include	"config.h"
-#endif
-
 #include	"cgi.h"
 
 #if	HAVE_UNISTD_H
