@@ -1,5 +1,5 @@
 /*
-** Copyright 2000-2006 Double Precision, Inc.
+** Copyright 2000-2009 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -54,6 +54,7 @@
 #include <sys/socket.h>
 #include <sys/un.h>
 
+#include	<courierauth.h>
 #include	"courier.h"
 #include	"liblock/config.h"
 #include	"liblock/liblock.h"
@@ -61,7 +62,7 @@
 #include	"sysconfdir.h"
 #include	"localstatedir.h"
 
-static const char rcsid[]="$Id: ldapaliasd.c,v 1.28 2006/11/12 15:33:23 mrsam Exp $";
+static const char rcsid[]="$Id: ldapaliasd.c,v 1.29 2009/12/19 00:59:59 mrsam Exp $";
 
 static LDAP *my_ldap_fp=0;
 static const char *basedn;
@@ -262,7 +263,25 @@ static LDAPMessage *search_attr(const char *filter, const char *attr)
 	return result;
 }
 
+static int search_maildrop2(const char *mail, const char *source, FILE *outfp);
+
 static int search_maildrop(const char *mail, const char *source, FILE *outfp)
+{
+	int rc;
+	char *escaped=courier_auth_ldap_escape(mail);
+
+	if (!escaped)
+	{
+		syslog(LOG_DAEMON|LOG_CRIT, "malloc failed: %m");
+		return(0);
+	}
+
+	rc=search_maildrop2(escaped, source, outfp);
+	free(escaped);
+	return rc;
+}
+
+static int search_maildrop2(const char *mail, const char *source, FILE *outfp)
 {
 	char *filter;
 	char *p;
