@@ -24,7 +24,7 @@
 #include	<syslog.h>
 #endif
 
-static const char rcsid[]="$Id: lcclog.c,v 1.7 2004/10/23 15:54:02 mrsam Exp $";
+static const char rcsid[]="$Id: lcclog.c,v 1.8 2008/01/05 02:58:36 mrsam Exp $";
 
 static int log_opened=0;
 static char logbuf[1024];
@@ -59,6 +59,10 @@ void clog_open_syslog(const char *module)
 
 void clog_open_stderr(const char *module)
 {
+#ifdef HAVE_SETVBUF_IOLBF
+	setvbuf(stderr, NULL, _IOLBF, BUFSIZ);
+#endif
+
 	log_opened=1;
 	logmodule=module;
 	clog_msg_send_func=clog_msg_send_stderr;
