@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2000 Double Precision, Inc.
+** Copyright 1998 - 2007 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -8,7 +8,7 @@
 #include	"lcrwstaticlist.h"
 #include	<string.h>
 
-static const char rcsid[]="$Id: lcrwstatic.c,v 1.2 2000/07/30 01:08:09 mrsam Exp $";
+static const char rcsid[]="$Id: lcrwstatic.c,v 1.3 2007/01/06 02:12:56 mrsam Exp $";
 
 extern struct rw_static_info rw_static[];
 
@@ -21,7 +21,7 @@ extern struct rw_static_info rw_static[];
 	We simply go through the list, and feed each module to rw_install.
 */
 
-int rw_init(const char *name)
+int rw_init_courier(const char *name)
 {
 unsigned	i;
 int	err=0;
