@@ -1,5 +1,5 @@
 /*
-** Copyright 2002-2004 Double Precision, Inc.
+** Copyright 2002-2009 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -13,8 +13,11 @@
 #include	"comfax.h"
 #include	"rfc822/rfc822.h"
 #include	"waitlib/waitlib.h"
+#include	"unicode/unicode.h"
 #include	"numlib/numlib.h"
 #include	<stdlib.h>
+#include	<locale.h>
+#include	<langinfo.h>
 #include	<string.h>
 #include	<ctype.h>
 #include	<signal.h>
@@ -48,10 +51,12 @@
 #include	"sendfax.h"
 #include	"faxtmpdir.h"
 
-static const char rcsid[]="$Id: courierfax.c,v 1.7 2005/02/07 23:55:22 mrsam Exp $";
+static const char rcsid[]="$Id: courierfax.c,v 1.8 2009/11/08 18:14:47 mrsam Exp $";
 
 static void fax(struct moduledel *);
 
+const struct unicode_info *default_charset;
+
 /*
 **  Kill the child process.
 */
@@ -75,6 +80,13 @@ int main(int argc, char **argv)
 	int waitstat;
 	const char *cp;
 
+	setlocale(LC_ALL, "");
+	default_charset=unicode_find(nl_langinfo(CODESET));
+	setlocale(LC_ALL, "C");
+
+	if (!default_charset)
+		default_charset= &unicode_ISO8859_1;
+
 	clog_open_syslog("courierfax");
 	if (chdir(getenv("COURIER_HOME")))
 		clog_msg_errno();
@@ -416,6 +428,16 @@ static void fax(struct moduledel *p)
 			for (pp=page_list; pp; pp=pp->next)
 				++page_cnt;
 
+#if 0
+			while (page_list)
+			{
+				unlink(page_list->filename);
+				page_list=page_list->next;
+			}
+
+			exit(0);
+#endif
+
 			argvec=(char **)courier_malloc(sizeof(char *)*
 						       (page_cnt+10));
 
