@@ -1,5 +1,5 @@
 /*
-** Copyright 2002 Double Precision, Inc.
+** Copyright 2002-2009 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -21,6 +21,7 @@
 #include "rfc2045/rfc2045charset.h"
 #include "numlib/numlib.h"
 #include "gpglib/gpglib.h"
+#include "unicode/unicode.h"
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -51,13 +52,15 @@
 #endif
 #endif
 
-static const char rcsid[]="$Id: faxconvert.c,v 1.5 2006/01/23 23:22:10 mrsam Exp $";
+static const char rcsid[]="$Id: faxconvert.c,v 1.7 2009/11/15 02:10:38 mrsam Exp $";
 
 #include "filterbindir.h"
 #include "faxtmpdir.h"
 
 #define SUBTMPDIR FAXTMPDIR "/.tmp"
 
+extern const struct unicode_info *default_charset;
+
 void rfc2045_error(const char *errmsg)
 {
 	fprintf(stderr, "faxconvert: %s\n", errmsg);
@@ -800,8 +803,15 @@ static int convert_cover_page(struct rfc2045 *rfcp,
 		{
 			if (hsubject)
 				free(hsubject);
-			hsubject=rfc2047_decode_enhanced(hbuf.value,
-							 RFC2045CHARSET);
+
+			hsubject=rfc822_display_hdrvalue_tobuf(hbuf.header,
+							       hbuf.value,
+							       default_charset
+							       ->chset,
+							       NULL, NULL);
+
+			if (!hsubject)
+				hsubject=strdup(hbuf.value);
 		}
 
 		if (strcmp(hbuf.header, "date") == 0)
@@ -864,29 +874,36 @@ static int convert_cover_page(struct rfc2045 *rfcp,
 /*
 ** Grab the names from the RFC 822/2045/2047-formatted header */
 
-static void cnt_names(char c, void *vp)
+static void cnt_names(const char *ptr, size_t cnt, void *vp)
 {
 	int *ip=(int *)vp;
+	size_t i;
 
-	if (c == '\n')
+	for (i=0; i<cnt; i++)
 	{
-		*ip += 2;
-		return;
+		if (ptr[i] == '\n')
+			++*ip;
+		++*ip;
 	}
-	++*ip;
 }
 
-static void save_names(char c, void *vp)
+static void save_names(const char *ptr, size_t cnt, void *vp)
 {
 	char **ip=(char **)vp;
+	size_t i;
 
-	if (c == '\n')
+	for (i=0; i<cnt; i++)
 	{
-		* (*ip)++ = ',';
-		*(*ip)++ = ' ';
-		return;
+		if (ptr[i] == '\n')
+		{
+			*(*ip)++ = ',';
+			*(*ip)++ = ' ';
+		}
+		else
+		{
+			*(*ip)++ = ptr[i];
+		}
 	}
-	*(*ip)++ = c;
 }
 
 static char *convnames(const char *pp)
@@ -894,7 +911,7 @@ static char *convnames(const char *pp)
 	struct rfc822t *t;
 	struct rfc822a *a;
 	int al;
-	char *q, *p;
+	char *q, *p=NULL;
 
 	t=rfc822t_alloc_new(pp ? pp:"", NULL, NULL);
 	if (!t)
@@ -910,22 +927,25 @@ static char *convnames(const char *pp)
 	}
 
 	al=1;
-	rfc822_namelist(a, cnt_names, &al);
 
-	q=p=courier_malloc(al+1);
+	if (rfc822_display_namelist(a, default_charset->chset,
+				    cnt_names, &al) == 0)
+	{
+		q=p=courier_malloc(al+1);
 
-	rfc822_namelist(a, save_names, &q);
+		if (rfc822_display_namelist(a, default_charset->chset,
+					    save_names, &q) == 0)
+		{
+			if (q - p >= 2 && q[-1] == ' ' && q[-2] == ',')
+				/* Trailing comma */
+				q -= 2;
 
-	if (q - p >= 2 && q[-1] == ' ' && q[-2] == ',') /* Trailing comma */
-		q -= 2;
-
-	*q=0;
+			*q=0;
+		}
+	}
 	rfc822a_free(a);
 	rfc822t_free(t);
-
-	q=rfc2047_decode_enhanced(p, RFC2045CHARSET);
-	free(p);
-	return (q);
+	return (p);
 }
 
 #if 0
