@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2006 Double Precision, Inc.
+** Copyright 1998 - 2009 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -54,7 +54,7 @@
 #include	"liblock/liblock.h"
 #include	"liblock/mail.h"
 
-static const char rcsid[]="$Id: deliver.c,v 1.26 2009/06/27 16:32:38 mrsam Exp $";
+static const char rcsid[]="$Id: deliver.c,v 1.28 2010/01/13 01:32:02 mrsam Exp $";
 
 extern char *local_dotcourier(const char *, const char *, const char **);
 extern char *local_extension();
@@ -226,11 +226,6 @@ char	*bs;
 
 /* Minor helper function */
 
-void print_stdout(char c, void *p)
-{
-	putchar(c);
-}
-
 static void dodel(const char *username, const char *userhome,
 	FILE *c, char *ctl,
 	const char *extension, const char *sender, const char *receipient,
@@ -365,9 +360,10 @@ const char *curtime;
 
 		if (*ctl == '&' || *ctl == '!')	++ctl;	/* Legacy */
 		{
-		const char *addresses=ctl;
-		struct rfc822t *tokens;
-		struct rfc822a *addrlist;
+			const char *addresses=ctl;
+			struct rfc822t *tokens;
+			struct rfc822a *addrlist;
+			int n;
 
 			ctl=skip_eol(ctl, 1);
 			if ((tokens=rfc822t_alloc_new(addresses, NULL,
@@ -378,7 +374,25 @@ const char *curtime;
 				exit(EX_TEMPFAIL);
 			}
 
-			rfc822_addrlist(addrlist, print_stdout, 0);
+			for (n=0; n<addrlist->naddrs; ++n)
+			{
+				char *p;
+
+				if (addrlist->addrs[n].tokens == NULL)
+					continue;
+
+				p=rfc822_display_addr_tobuf(addrlist, n,
+							    NULL);
+
+				if (!p)
+				{
+					perror(addresses);
+					exit(EX_TEMPFAIL);
+				}
+
+				printf("%s\n", p);
+				free(p);
+			}
 			rfc822a_free(addrlist);
 			rfc822t_free(tokens);
 			fflush(stdout);
@@ -811,7 +825,11 @@ const char *shell=getenv("SHELL");
 			args[3]=0;
 		}
 		lseek(0, 0L, SEEK_SET);
-		execve(p, (char **)args, envs);
+
+		for (i=0; envs[i]; ++i)
+			putenv(envs[i]);
+
+		execv(p, (char **)args);
 		fprintf(stderr, "Cannot run %s\n", p);
 		_exit(EX_TEMPFAIL);
 	}
