@@ -35,7 +35,7 @@
 
 #define DEFAULTNAME	"alias@"
 
-static const char rcsid[]="$Id: local.c,v 1.28 2007/10/17 02:04:01 mrsam Exp $";
+static const char rcsid[]="$Id: local.c,v 1.29 2010/03/16 22:13:38 mrsam Exp $";
 
 extern char *local_dotcourier(const char *, const char *, const char **);
 
@@ -770,7 +770,7 @@ const char *quota;
 	while ((l=read(p[0], errbuf, sizeof(errbuf))) > 0)
 	{
 		if (l > bufsize-1)
-			l=bufsize-1-l;
+			l=bufsize-1;
 		memcpy(buf, errbuf, l);
 		buf += l;
 		bufsize -= l;
