@@ -284,7 +284,7 @@ unsigned msglen, fwdlen;
 
 static void save_submit_errmsg(const char *p)
 {
-	size_t l=strlen(p);
+	size_t l=strlen(p ? p:"");
 
 	if (l > errleft)
 		l=errleft;
