@@ -37,7 +37,7 @@
 
 extern void esmtpd();
 
-static const char rcsid[]="$Id: sendmail.c,v 1.13 2004/05/09 17:47:03 mrsam Exp $";
+static const char rcsid[]="$Id: sendmail.c,v 1.14 2007/10/15 01:46:46 mrsam Exp $";
 
 static struct passwd *mypwd()
 {
@@ -344,15 +344,6 @@ char	*gecosname=0;
 	return (p);
 }
 
-static RETSIGTYPE bye(int signum)
-{
-	submit_cancel_async();
-	_exit(0);
-#if	RETSIGTYPE != void
-	return (0);
-#endif
-}
-
 static void exit_submit(int errcode)
 {
 	if (errcode == -5)
@@ -619,9 +610,6 @@ int     submit_errcode;
 		exit(EX_TEMPFAIL);
 	}
 
-	signal(SIGALRM, bye);
-	alarm( 30 * 60 );
-
 	if (tostdout)
 		submit_to=stdout;
 	else
@@ -665,7 +653,6 @@ int     submit_errcode;
 		putc(c, submit_to);
 	}
 	fflush(submit_to);
-	alarm(0);
 	signal(SIGINT, SIG_IGN);
 	signal(SIGTERM, SIG_IGN);
 	signal(SIGHUP, SIG_IGN);
