@@ -2,9 +2,9 @@
 #
 # TITLE: Inbound ESMTP
 #
-# $Id: admin-30esmtp.pl,v 1.6 2001/07/15 00:58:39 mrsam Exp $
+# $Id: admin-30esmtp.pl,v 1.11 2009/07/30 02:29:54 mrsam Exp $
 #
-# Copyright 2001 Double Precision, Inc.  See COPYING for
+# Copyright 2001-2004 Double Precision, Inc.  See COPYING for
 # distribution information.
 
 use webadmin;
@@ -88,39 +88,59 @@ if ($cgi->param("Save"))
 {
     ReplaceEnvVarConfigFile("esmtpd", "ESMTPDSTART",
 			    $cgi->param("ENABLED") ? "YES":"NO");
+    ReplaceEnvVarConfigFile("esmtpd-ssl", "ESMTPDSSLSTART",
+			    $cgi->param("ENABLED_SSL") ? "YES":"NO");
     ReplaceEnvVarConfigFile("esmtpd-msa", "ESMTPDSTART",
 			    $cgi->param("ENABLED_MSA") ? "YES":"NO");
 
     ReplaceEnvVarConfigFile("esmtpd", "NOADDMSGID",
 			    $cgi->param("MSGID") ? "0":"1");
+    ReplaceEnvVarConfigFile("esmtpd-ssl", "NOADDMSGID",
+			    $cgi->param("MSGID_SSL") ? "0":"1");
     ReplaceEnvVarConfigFile("esmtpd-msa", "NOADDMSGID",
 			    $cgi->param("MSGID_MSA") ? "0":"1");
 
     ReplaceEnvVarConfigFile("esmtpd", "NOADDDATE",
 			    $cgi->param("DATE") ? "0":"1");
+    ReplaceEnvVarConfigFile("esmtpd-ssl", "NOADDDATE",
+			    $cgi->param("DATE_SSL") ? "0":"1");
     ReplaceEnvVarConfigFile("esmtpd-msa", "NOADDDATE",
 			    $cgi->param("DATE_MSA") ? "0":"1");
 
     ReplaceEnvVarConfigFile("esmtpd", "AUTH_REQUIRED",
 			    $cgi->param("AUTH") ? "1":"0");
+    ReplaceEnvVarConfigFile("esmtpd-ssl", "AUTH_REQUIRED",
+			    $cgi->param("AUTH_SSL") ? "1":"0");
     ReplaceEnvVarConfigFile("esmtpd-msa", "AUTH_REQUIRED",
 			    $cgi->param("AUTH_MSA") ? "1":"0");
 
     ReplaceEnvVarConfigFile("esmtpd", "BOFHCHECKDNS",
 			    $cgi->param("CHECKDNS") ? "1":"0");
+    ReplaceEnvVarConfigFile("esmtpd-ssl", "BOFHCHECKDNS",
+			    $cgi->param("CHECKDNS_SSL") ? "1":"0");
     ReplaceEnvVarConfigFile("esmtpd-msa", "BOFHCHECKDNS",
 			    $cgi->param("CHECKDNS_MSA") ? "1":"0");
 
     ReplaceEnvVarConfigFile("esmtpd", "MAXDAEMONS", $cgi->param("MAXDAEMONS"));
+    ReplaceEnvVarConfigFile("esmtpd-ssl", "MAXDAEMONS",
+			    $cgi->param("MAXDAEMONS_SSL"));
     ReplaceEnvVarConfigFile("esmtpd-msa", "MAXDAEMONS",
 			    $cgi->param("MAXDAEMONS_MSA"));
     ReplaceEnvVarConfigFile("esmtpd", "MAXPERIP", $cgi->param("MAXPERIP"));
+    ReplaceEnvVarConfigFile("esmtpd-ssl", "MAXPERIP",
+			    $cgi->param("MAXPERIP_SSL"));
     ReplaceEnvVarConfigFile("esmtpd-msa", "MAXPERIP",
 			    $cgi->param("MAXPERIP_MSA"));
     ReplaceEnvVarConfigFile("esmtpd", "MAXPERC", $cgi->param("MAXPERC"));
+    ReplaceEnvVarConfigFile("esmtpd-ssl", "MAXPERC",
+			    $cgi->param("MAXPERC_SSL"));
     ReplaceEnvVarConfigFile("esmtpd-msa", "MAXPERC",
 			    $cgi->param("MAXPERC_MSA"));
 
+    $dodrop=$cgi->param("DROP") || "";
+
+    ReplaceEnvVarConfigFile("esmtpd", "DROP", $dodrop ? "-drop":"");
+
     my $esmtp=ReadEnvVarConfigFile("esmtpd");
 
 
@@ -132,9 +152,6 @@ if ($cgi->param("Save"))
     }
 
     my $esmtpauth=join(" ", @a);
-    my $authmodules="";
-
-    $authmodules=$$esmtp{'AUTHMODULES_WEBADMIN'} if $esmtpauth;
 
     ReplaceEnvVarConfigFile("esmtpd", "ESMTPAUTH", $esmtpauth);
 
@@ -147,10 +164,7 @@ if ($cgi->param("Save"))
 
     $esmtpauth=join(" ", @a);
 
-    $authmodules=$$esmtp{'AUTHMODULES_WEBADMIN'} if $esmtpauth;
-
     ReplaceEnvVarConfigFile("esmtpd", "ESMTPAUTH_TLS", $esmtpauth);
-    ReplaceEnvVarConfigFile("esmtpd", "AUTHMODULES", $authmodules);
 
     $changed=1;
 
@@ -165,7 +179,12 @@ if ($cgi->param("Add"))
 
     $bl .= " " if $bl;
 
-    if ($radio ne "CUSTOM")
+    $radio =~ s/\s//g;
+
+    if ($radio eq "")
+      {
+      }
+    elsif ($radio ne "CUSTOM")
     {
 	my $suffix="";
 
@@ -220,7 +239,7 @@ if ($cgi->param("AddAccess"))
 	$ip=undef if $@;
     }
 
-    if ($ip =~ /^[a-fA-F0-9\.:\-\/]+$/)
+    if ($ip =~ /^[a-fA-F0-9\.:\-\/]+$/ || $ip eq "*")
     {
 	if ($v eq "BOUNCE")
 	{
@@ -231,6 +250,11 @@ if ($cgi->param("AddAccess"))
 	    $v="allow,BLOCK=\"$v\"";
 	}
 
+	my $bofh=$cgi->param("bofhbadmime");
+
+	$v .= ",BOFHBADMIME=$bofh"
+	  if $bofh eq "accept" || $bofh eq "reject";
+
 	my $l=join("\n",
 		   ReadMultiLineConfigFile("smtpaccess/webadmin"),
 		   "$ip\t$v\n");
@@ -302,6 +326,7 @@ if ($changed)
 {
     changed("$sbindir/esmtpd stop ; . $sysconfdir/esmtpd ; test \"\$ESMTPDSTART\" != YES || $sbindir/esmtpd start");
     changed("$sbindir/esmtpd-msa stop ; . $sysconfdir/esmtpd-msa ; test \"\$ESMTPDSTART\" != YES || $sbindir/esmtpd-msa start");
+    changed("$sbindir/esmtpd-ssl stop ; . $sysconfdir/esmtpd-ssl ; test \"\$ESMTPDSSLSTART\" != YES || $sbindir/esmtpd-ssl start");
 
     $errstr="\@SAVED\@";
 }
@@ -324,7 +349,9 @@ if ($cgi->param("delacceptmailfor"))
 
 
 my $esmtp=ReadEnvVarConfigFile("esmtpd");
+my $ssl=ReadEnvVarConfigFile("esmtpd-ssl");
 my $msa=ReadEnvVarConfigFile("esmtpd-msa");
+my $dodrop=$$esmtp{"DROP"} || "";
 
 my $esmtpauth="";
 my $esmtpauth_tls="";
@@ -336,8 +363,8 @@ grep {
 } grep (/./, split(/\s+/, $$esmtp{'ESMTPAUTH'}));
 
 grep {
-    $esmtpauth .= "<input type=checkbox name='SASL_$_'"
-	. ($esmtpauthhash{$_} ? " checked":"") . ">&nbsp;<tt>$_</tt><br>";
+    $esmtpauth .= "<input type=\"checkbox\" name='SASL_$_'"
+	. ($esmtpauthhash{$_} ? " checked=\"checked\"":"") . " />&nbsp;<tt>$_</tt><br />";
 } sort grep (/./, split(/\s+/, $$esmtp{'ESMTPAUTH_WEBADMIN'}));
 
 %esmtpauthhash = ();
@@ -347,11 +374,11 @@ grep {
 } grep (/./, split(/\s+/, $$esmtp{'ESMTPAUTH_TLS'}));
 
 grep {
-    $esmtpauth_tls .= "<input type=checkbox name='SASL_TLS_$_'"
-	. ($esmtpauthhash{$_} ? " checked":"") . ">&nbsp;<tt>$_</tt><br>";
+    $esmtpauth_tls .= "<input type=\"checkbox\" name='SASL_TLS_$_'"
+	. ($esmtpauthhash{$_} ? " checked=\"checked\"":"") . " />&nbsp;<tt>$_</tt><br />";
 } sort grep (/./, split(/\s+/, $$esmtp{'ESMTPAUTH_TLS_WEBADMIN'}));
 
-my $blacklists="<table border=0 cellspacing=16>";
+my $blacklists="<table border=\"0\" cellspacing=\"16\">";
 
 foreach (parsebl($$esmtp{'BLACKLISTS'}))
 {
@@ -363,7 +390,7 @@ foreach (parsebl($$esmtp{'BLACKLISTS'}))
     my $temp_cgi=new CGI({
 	"deleteblacklist" => "$zone$ip"});
 
-    $blacklists .= "<tr><td colspan=2><tt>$zone$ip</tt></td><td><a href=\"30esmtp?"
+    $blacklists .= "<tr><td colspan=\"2\"><tt>$zone$ip</tt></td><td><a href=\"30esmtp?"
 	. $temp_cgi->query_string . "\">\@DELETE\@</a></td></tr>";
 }
 
@@ -399,7 +426,7 @@ foreach (keys %{readaliases()})
     $acceptdomains{$1}="\@ISVIRTUAL\@";
 }
 
-my $acceptHTML="<table border=0 cellspacing=16>";
+my $acceptHTML="<table border=\"0\" cellspacing=\"16\">";
 
 my @l=ReadMultiLineConfigFile("esmtpacceptmailfor.dir/webadmin");
 
@@ -421,28 +448,42 @@ display_form("admin-30esmtp.html",
 	     {
 		 "ACCEPTMAILFORLIST" => $acceptHTML,
 		 "BLACKLISTS" => $blacklists,
-		 "ENABLED" => "<input type=checkbox name=ENABLED" . (($$esmtp{"ESMTPDSTART"} =~ /[yY]/) ? " checked":"") . ">",
-		 "ENABLED_MSA" => "<input type=checkbox name='ENABLED_MSA'" . ($$msa{"ESMTPDSTART"} =~ /[yY]/ ? " checked":"") . ">",
+		 "NOTDROP" => "<input type=\"radio\" name='DROP' value=\"\""
+		     . (!$dodrop ? " checked=\"checked\"":"")
+		     . " />",
+		 "DROP" => "<input type=\"radio\" name='DROP' value=\"drop\""
+		     . ($dodrop ? " checked=\"checked\"":"")
+		     . " />",
+		 "ENABLED" => "<input type=\"checkbox\" name='ENABLED'" . (($$esmtp{"ESMTPDSTART"} =~ /[yY]/) ? " checked=\"checked\"":"") . " />",
+		 "ENABLED_SSL" => "<input type=\"checkbox\" name='ENABLED_SSL'" . ($$ssl{"ESMTPDSSLSTART"} =~ /[yY]/ ? " checked=\"checked\"":"") . " />",
+		 "ENABLED_MSA" => "<input type=\"checkbox\" name='ENABLED_MSA'" . ($$msa{"ESMTPDSTART"} =~ /[yY]/ ? " checked=\"checked\"":"") . " />",
 
-		 "MSGID" => "<input type=checkbox name=MSGID" . ($$esmtp{"NOADDMSGID"} ? "":" checked") . ">",
-		 "MSGID_MSA" => "<input type=checkbox name='MSGID_MSA'" . ($$msa{"NOADDMSGID"} ? "":" checked") . ">",
-		 "DATE" => "<input type=checkbox name=DATE" . ($$esmtp{"NOADDDATE"} ? "":" checked") . ">",
-		 "DATE_MSA" => "<input type=checkbox name='DATE_MSA'" . ($$msa{"NOADDDATE"} ? "":" checked") . ">",
+		 "MSGID" => "<input type=\"checkbox\" name='MSGID'" . ($$esmtp{"NOADDMSGID"} ? "":" checked=\"checked\"") . " />",
+		 "MSGID_SSL" => "<input type=\"checkbox\" name='MSGID_SSL'" . ($$ssl{"NOADDMSGID"} ? "":" checked=\"checked\"") . " />",
+		 "MSGID_MSA" => "<input type=\"checkbox\" name='MSGID_MSA'" . ($$msa{"NOADDMSGID"} ? "":" checked=\"checked\"") . " />",
+		 "DATE" => "<input type=\"checkbox\" name='DATE'" . ($$esmtp{"NOADDDATE"} ? "":" checked=\"checked\"") . " />",
+		 "DATE_SSL" => "<input type=\"checkbox\" name='DATE_SSL'" . ($$ssl{"NOADDDATE"} ? "":" checked=\"checked\"") . " />",
+		 "DATE_MSA" => "<input type=\"checkbox\" name='DATE_MSA'" . ($$msa{"NOADDDATE"} ? "":" checked=\"checked\"") . " />",
 
-		 "AUTH" => "<input type=checkbox name=AUTH" . ($$esmtp{"AUTH_REQUIRED"} ? " checked":"") . ">",
-		 "AUTH_MSA" => "<input type=checkbox name='AUTH_MSA'" . ($$msa{"AUTH_REQUIRED"} ? " checked":"") . ">",
+		 "AUTH" => "<input type=\"checkbox\" name='AUTH'" . ($$esmtp{"AUTH_REQUIRED"} ? " checked=\"checked\"":"") . " />",
+		 "AUTH_SSL" => "<input type=\"checkbox\" name='AUTH_SSL'" . ($$ssl{"AUTH_REQUIRED"} ? " checked=\"checked\"":"") . " />",
+		 "AUTH_MSA" => "<input type=\"checkbox\" name='AUTH_MSA'" . ($$msa{"AUTH_REQUIRED"} ? " checked=\"checked\"":"") . " />",
 
-		 "CHECKDNS" => "<input type=checkbox name=CHECKDNS" . ($$esmtp{"BOFHCHECKDNS"} ? " checked":"") . ">",
-		 "CHECKDNS_MSA" => "<input type=checkbox name='CHECKDNS_MSA'" . ($$msa{"BOFHCHECKDNS"} ? " checked":"") . ">",
+		 "CHECKDNS" => "<input type=\"checkbox\" name='CHECKDNS'" . ($$esmtp{"BOFHCHECKDNS"} ? " checked=\"checked\"":"") . " />",
+		 "CHECKDNS_SSL" => "<input type=\"checkbox\" name='CHECKDNS_SSL'" . ($$ssl{"BOFHCHECKDNS"} ? " checked=\"checked\"":"") . " />",
+		 "CHECKDNS_MSA" => "<input type=\"checkbox\" name='CHECKDNS_MSA'" . ($$msa{"BOFHCHECKDNS"} ? " checked=\"checked\"":"") . " />",
 
 		 "ESMTPAUTH" => $esmtpauth,
 		 "ESMTPAUTH_TLS" => $esmtpauth_tls,
 
 		 "MAXDAEMONS" => $$esmtp{'MAXDAEMONS'},
+		 "MAXDAEMONS_SSL" => $$ssl{'MAXDAEMONS'},
 		 "MAXDAEMONS_MSA" => $$msa{'MAXDAEMONS'},
 		 "MAXPERIP" => $$esmtp{'MAXPERIP'},
+		 "MAXPERIP_SSL" => $$ssl{'MAXPERIP'},
 		 "MAXPERIP_MSA" => $$msa{'MAXPERIP'},
 		 "MAXPERC" => $$esmtp{'MAXPERC'},
+		 "MAXPERC_SSL" => $$ssl{'MAXPERC'},
 		 "MAXPERC_MSA" => $$msa{'MAXPERC'},
 
 		 "ERROR" => $errstr,
