@@ -27,7 +27,7 @@
 
 #include	"imapwrite.h"
 
-static const char rcsid[]="$Id: imapwrite.c,v 1.7 2006/05/28 15:29:52 mrsam Exp $";
+static const char rcsid[]="$Id: imapwrite.c,v 1.8 2008/07/20 16:58:32 mrsam Exp $";
 
 static char outbuf[BUFSIZ];	/* Ye olde output buffer */
 static size_t outbuf_cnt=0;	/* How much stuff's in ye olde output buffer */
@@ -215,5 +215,12 @@ void write_error_exit(const char *funcname)
 	}
 	writes("\r\n");
 	writeflush();
+
+	if (funcname && *funcname)
+	{
+		fprintf(stderr, "ERR: %s: %s\n", getenv("AUTHENTICATED"),
+			funcname);
+		fflush(stderr);
+	}
 	_exit(1);
 }
