@@ -1,7 +1,7 @@
 #ifndef	maildir_h
 #define	maildir_h
 
-static const char maildir_h_rcsid[]="$Id: maildir.h,v 1.2 1999/08/02 05:02:26 mrsam Exp $";
+static const char maildir_h_rcsid[]="$Id: maildir.h,v 1.4 2004/01/15 03:12:13 mrsam Exp $";
 
 ///////////////////////////////////////////////////////////////////////
 //
@@ -16,6 +16,8 @@ class	Mio;
 
 class Maildir {
 	int	is_open;
+	int	is_afs;
+	Buffer	maildirRoot;
 public:
 	Buffer	tmpname;
 	Buffer	newname;
