@@ -9,9 +9,9 @@
 #include	"numlib.h"
 #include	<string.h>
 
-static const char rcsid[]="$Id: strinot.c,v 1.3 2000/05/27 04:59:26 mrsam Exp $";
+static const char rcsid[]="$Id: strinot.c,v 1.4 2003/01/05 04:01:17 mrsam Exp $";
 
-char *str_ino_t(ino_t t, char *arg)
+char *libmail_str_ino_t(ino_t t, char *arg)
 {
 char	buf[NUMBUFSIZE];
 char	*p=buf+sizeof(buf)-1;
