@@ -1,9 +1,9 @@
 /*
-** Copyright 2001-2004 Double Precision, Inc.  See COPYING for
+** Copyright 2001-2009 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
-static const char rcsid[]="$Id: pcp.c,v 1.9 2009/06/27 16:32:38 mrsam Exp $";
+static const char rcsid[]="$Id: pcp.c,v 1.10 2009/11/08 18:14:47 mrsam Exp $";
 
 #include "config.h"
 #include <stdio.h>
@@ -13,6 +13,7 @@ static const char rcsid[]="$Id: pcp.c,v 1.9 2009/06/27 16:32:38 mrsam Exp $";
 #include <errno.h>
 #include <signal.h>
 #include <unistd.h>
+#include <langinfo.h>
 #if HAVE_TERMIOS_H
 #include <termios.h>
 #endif
@@ -24,10 +25,12 @@ static const char rcsid[]="$Id: pcp.c,v 1.9 2009/06/27 16:32:38 mrsam Exp $";
 #include <sys/socket.h>
 #include <sys/un.h>
 #include <pwd.h>
+#include <rfc822/rfc822.h>
 #include <rfc822/rfc2047.h>
 #include <rfc822/rfc822hdr.h>
 #include <rfc2045/rfc2045.h>
 #include <rfc2045/rfc2045charset.h>
+#include <unicode/unicode.h>
 #include <numlib/numlib.h>
 
 #define PCP_ERRMSG(s) gettext(s)
@@ -246,6 +249,7 @@ struct PCP *open_calendar()
 	}
 
 	pcp=pcp_open_dir(p, pw->pw_name);
+	free(p);
 
 	if (!pcp)
 	{
@@ -572,6 +576,13 @@ static int save_retr_headers(struct PCP_retr *, const char *,
 			     const char *, void *);
 static int save_retr_status(struct PCP_retr *, int, void *);
 
+static void dump_rfc822_hdr(const char *ptr, size_t cnt,
+			    void *dummy)
+{
+	fwrite(ptr, cnt, 1, stdout);
+}
+
+
 static void list(int argn, int argc, char **argv, int flags)
 {
 	struct listinfo listinfo;
@@ -765,12 +776,25 @@ static void list(int argn, int argc, char **argv, int flags)
 					     ary[i]->from,
 					     ary[i]->to) < 0)
 				strcpy(fromto, "******");
-			printf("%-*s %s%s%s\n", (int)maxl, fromto,
+			printf("%-*s %s%s", (int)maxl, fromto,
 			       ary[i]->status & LIST_CANCELLED
 			       ? gettext("CANCELLED: "):"",
 			       ary[i]->status & LIST_BOOKED
-			       ? gettext("(event not yet commited)"):"",
-			       ary[i]->subject ? ary[i]->subject:"");
+			       ? gettext("(event not yet commited) "):"");
+
+			if (rfc822_display_hdrvalue("subject",
+						    ary[i]->subject
+						    ? ary[i]->subject:"",
+						    charset,
+						    dump_rfc822_hdr,
+						    NULL, NULL) < 0)
+			{
+				printf("%s", 
+				       ary[i]->subject
+				       ? ary[i]->subject:"");
+			}
+			printf("\n");
+
 			if (flags & FLAG_LIST_EVENT_ID)
 				printf("%-*s(%s)\n", (int)maxl, "",
 				       ary[i]->eventid);
@@ -1127,15 +1151,15 @@ static int list_msg_rfc822(struct rfc2045 *rfc, FILE *fp)
 
 	while (rfc822hdr_read(&h, fp, &pos, start_body) == 0)
 	{
-		char *hh=rfc2047_decode_enhanced(h.value, charset);
+		printf("%s: ", h.header);
 
-		if (!hh)
+		if (rfc822_display_hdrvalue(h.header, h.value, charset,
+					    dump_rfc822_hdr, NULL, NULL) < 0)
 		{
-			perror("rfc2047_decode_enhanced");
-			exit(1);
+			printf("%s", h.value);
 		}
-		printf("%s: %s\n", h.header, hh);
-		free(hh);
+
+		printf("\n");
 	}
 	rfc822hdr_free(&h);
 	printf("\n");
@@ -1607,6 +1631,17 @@ static void doconnectwrite(int fd, const char *p, int cnt)
 
 static void usage()
 {
+	const char *charset=RFC2045CHARSET;
+
+	{
+		const char *p=nl_langinfo(CODESET);
+
+		if (unicode_find(p) != NULL)
+			charset=p;
+
+	}
+
+
 	fprintf(stderr,
 		gettext("Usage: pcp [options] [command]\n"
 			"\n"
@@ -1616,7 +1651,7 @@ static void usage()
 			"   -C charset   - specify your local charset (default %s)\n"
 			"   -m           - standard input is already a MIME-formatted message\n"
 			"   -e           - list event ids\n"
-			"\n"), RFC2045CHARSET);
+			"\n"), charset);
 
 	fprintf(stderr, "%s",
 		gettext(
@@ -1686,6 +1721,14 @@ int main(int argc, char **argv)
 	setlocale(LC_ALL, "");
 	textdomain("pcp");
 
+	{
+		const char *p=nl_langinfo(CODESET);
+
+		if (unicode_find(p) != NULL)
+			charset=p;
+
+	}
+
 	while ((optchar=getopt(argc, argv, "emcs:C:")) >= 0)
 	{
 		switch (optchar) {
