@@ -6,7 +6,7 @@
 ** distribution information.
 */
 
-static const char pcpdauth_h_rcsid[]="$Id: pcpdauth.h,v 1.1 2001/10/26 04:01:27 mrsam Exp $";
+static const char pcpdauth_h_rcsid[]="$Id: pcpdauth.h,v 1.2 2004/10/21 01:12:57 mrsam Exp $";
 
 #include "config.h"
 #include <sys/types.h>
@@ -14,8 +14,6 @@ static const char pcpdauth_h_rcsid[]="$Id: pcpdauth.h,v 1.1 2001/10/26 04:01:27
 
 struct userid_callback {
 	const char *userid;
-	const char *driver;
-
 	const char *homedir;
 	const char *maildir;
 	uid_t uid;
@@ -24,12 +22,12 @@ struct userid_callback {
 	void *callback_arg;
 } ;
 
-int auth_userid(const char *, int (*)(struct userid_callback *, void *),
+int authpcp_userid(const char *, int (*)(struct userid_callback *, void *),
 		void *);
 
-int auth_login(const char *, const char *,
-	       int (*)(struct userid_callback *, void *),
-	       void *);
+int authpcp_login(const char *, const char *,
+		  int (*)(struct userid_callback *, void *),
+		  void *);
 
 
 char *auth_myhostname();
