@@ -8,6 +8,7 @@
 #endif
 #include	"rfc2045.h"
 #include	"rfc2045charset.h"
+#include	"rfc822/encode.h"
 #if	HAVE_UNISTD_H
 #include	<unistd.h>
 #endif
@@ -19,7 +20,7 @@
 #include       <strings.h>
 #endif
 
-/* $Id: rfc2045rewrite.c,v 1.12 2003/03/07 00:47:31 mrsam Exp $ */
+/* $Id: rfc2045rewrite.c,v 1.15 2006/11/04 20:20:30 mrsam Exp $ */
 
 static char *rw_boundary_root;
 static int rw_boundary_cnt;
@@ -33,11 +34,6 @@ static void *fdout_arg;
 static char fdout_buf[512];
 static char *fdout_ptr;
 static size_t fdout_left;
-
-/* Quoted printable encoding */
-static void qpe_start();
-static int qpe_do(const char *, size_t, void *);
-static void qpe_end();
 static int conv_err;
 
 static int fdout_flush()
@@ -138,6 +134,16 @@ size_t i,j;
 	return (fdout_add(v, i));
 }
 
+static int fdout_add_qp(const char *ptr, size_t cnt, void *dummy)
+{
+	return (fdout_add(ptr, cnt));
+}
+
+static int qpe_do(const char *p, size_t i, void *ptr)
+{
+	return libmail_encode( (struct libmail_encode_info *)ptr, p, i);
+}
+
 #define	TE(p)	((p)->rw_transfer_encoding ? \
 		(p)->rw_transfer_encoding: (p)->content_transfer_encoding)
 
@@ -198,6 +204,7 @@ static int dorw(struct rfc2045 *p)
 {
 int seen_mime=0;
 char	buf[BUFSIZ];
+struct libmail_encode_info qp_encode;
 int	c;
 int	bcnt;
 
@@ -315,8 +322,10 @@ int	bcnt;
 		conv_err=0;
 		if (convmode == RFC2045_RW_7BIT)
 		{
-			qpe_start();
-			rfc2045_cdecode_start(p, &qpe_do, 0);
+			libmail_encode_start(&qp_encode,
+					     "quoted-printable",
+					     fdout_add_qp, NULL);
+			rfc2045_cdecode_start(p, &qpe_do, &qp_encode);
 		}
 
 		if (convmode == RFC2045_RW_8BIT)
@@ -342,7 +351,8 @@ int	bcnt;
 		if (convmode == RFC2045_RW_7BIT)
 		{
 			rfc2045_cdecode_end(p);
-			qpe_end();
+			if (libmail_encode_end(&qp_encode))
+				conv_err=1;
 		}
 		if (convmode == RFC2045_RW_8BIT)
 		{
@@ -432,61 +442,13 @@ int	fd=dup(fdin_arg);
 		rc=dorw(p);
 		free(rw_boundary_root);
 	}
+	if (rc == 0 && fdout_ptr > fdout_buf
+	    && fdout_ptr[-1] != '\n')
+	{
+		fdout_add("\n", 1);
+	}
 	if (rc == 0 && fdout_ptr > fdout_buf)
 		rc=fdout_flush();
 	fclose(fdin);
 	return (rc);
 }
-
-static int qpe_pos;
-
-static void qpe_start()
-{
-	qpe_pos=0;
-}
-
-static int qpe_do(const char *p, size_t i, void *ptr)
-{
-size_t	j,k;
-
-	if (conv_err)	return (0);
-	for (j=k=0; j<i; j++)
-	{
-		if (p[j] == '\n')
-		{
-			if (fdout_add(p+k, j+1-k))	conv_err=1;
-			k=j+1;
-			qpe_pos=0;
-			continue;
-		}
-		if (qpe_pos >= 72)
-		{
-			if (fdout_add(p+k, j-k) ||
-				fdout_add("=\n", 2))	conv_err=1;
-			k=j;
-			qpe_pos=0;
-		}
-
-		if (p[j] < 32 || p[j] >= 127 || p[j] == '=')
-		{
-		char buf[3];
-		static char xdigit[16]="0123456789ABCDEF";
-		unsigned n= (unsigned char)p[j];
-
-			buf[0]='=';
-			buf[1]=xdigit[ n / 16];
-			buf[2]=xdigit[ n % 16];
-			if (fdout_add(p+k, j-k) ||
-				fdout_add(buf, 3))	conv_err=1;
-			qpe_pos += 2;
-			k=j+1;
-		}
-		++qpe_pos;
-	}
-	if (fdout_add(p+k, j-k))	conv_err=1;
-	return (0);
-}
-
-static void qpe_end()
-{
-}
