@@ -1,5 +1,5 @@
 /*
-** Copyright 2000-2008 Double Precision, Inc.
+** Copyright 2000-2009 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 #include	"config.h"
@@ -1343,7 +1343,7 @@ void tls_dump_connection_info(ssl_handle ssl,
 			      void (*dump_func)(const char *, int cnt, void *),
 			      void *dump_arg)
 {
-	SSL_CIPHER *cipher;
+	const SSL_CIPHER *cipher;
 
 	{
 		STACK_OF(X509) *peer_cert_chain=SSL_get_peer_cert_chain(ssl);
@@ -1406,7 +1406,7 @@ void tls_dump_connection_info(ssl_handle ssl,
 char *tls_get_encryption_desc(ssl_handle ssl)
 {
 	char protocolbuf[256];
-	SSL_CIPHER *cipher;
+	const SSL_CIPHER *cipher;
 	const char *c, *d;
 
 	cipher=SSL_get_current_cipher(ssl);
