@@ -1,11 +1,11 @@
 /*
-** Copyright 2000 Double Precision, Inc.
+** Copyright 2000-2003 Double Precision, Inc.
 ** See COPYING for distribution information.
 **
-** $Id: iso8859_convert.c,v 1.1 2000/10/07 19:04:10 mrsam Exp $
+** $Id: iso8859_convert.c,v 1.2 2003/03/07 00:47:31 mrsam Exp $
 */
 
-#include	"config.h"
+#include	"unicode_config.h"
 #include	"unicode.h"
 #include	<string.h>
 #include	<stdlib.h>
