@@ -1,10 +1,10 @@
 /*
-** Copyright 2000-2001 Double Precision, Inc.  See COPYING for
+** Copyright 2000-2009 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
 /*
-** $Id: addressbook.c,v 1.14 2008/06/14 14:42:51 mrsam Exp $
+** $Id: addressbook.c,v 1.17 2009/11/22 14:42:56 mrsam Exp $
 */
 
 #include	"sqwebmail.h"
@@ -20,10 +20,13 @@
 
 #define	ADDRESSBOOK	"sqwebmail-addressbook"
 
+extern const char *sqwebmail_content_charset;
+
 extern void output_attrencoded(const char *);
 extern void output_attrencoded_fp(const char *, FILE *);
 extern void output_urlencoded(const char *);
 extern void print_safe(const char *);
+extern void call_print_safe_to_stdout(const char *p, size_t cnt);
 
 static char *q_escape(const char *name)
 {
@@ -91,19 +94,16 @@ static void fix_nameaddr(const char *name, const char *addr,
 	*addrret=addresss;
 }
 
-void ab_add(const char *name, const char *address, const char *nick)
+static void ab_add_int(const char *name, const char *address, const char *nick)
 {
-char	*nicks, *names, *addresss, *p, *q;
-FILE	*fp;
-char	*header, *value;
+	char	*nicks, *names, *addresss, *p, *q;
+	FILE	*fp;
+	char	*header, *value;
 
-int	new_fd;
-char	*new_name;
-FILE	*new_fp;
-int	written;
-
-	if (*nick == 0 || *address == 0)
-		return;
+	int	new_fd;
+	char	*new_name;
+	FILE	*new_fp;
+	int	written;
 
 	/* Delete bad characters from nickname, name, address */
 
@@ -203,6 +203,35 @@ int	written;
 	free(new_name);
 }
 
+void ab_add(const char *name, const char *address, const char *nick)
+{
+	char *nick_utf8, *name_utf8, *addr_utf8;
+	const struct unicode_info *uiptr
+		=unicode_find(sqwebmail_content_charset);
+
+	if (*nick == 0 || *address == 0)
+		return;
+
+	if (!uiptr)
+		uiptr=&unicode_ISO8859_1;
+
+	nick_utf8=unicode_convert(nick, uiptr, &unicode_UTF8);
+	name_utf8=unicode_convert(name ? name:"", uiptr, &unicode_UTF8);
+	addr_utf8=unicode_convert(address, uiptr, &unicode_UTF8);
+
+	if (nick_utf8 && name_utf8 && addr_utf8)
+		ab_add_int(name_utf8, addr_utf8, nick_utf8);
+
+	if (nick_utf8)
+		free(nick_utf8);
+	if (name_utf8)
+		free(name_utf8);
+	if (addr_utf8)
+		free(addr_utf8);
+}
+
+/* note: we're always passing utf-8 to dodel() */
+
 static void dodel(const char *nick, struct rfc822a *a, int n,
 	const char *replace_name, const char *replace_addr)
 {
@@ -392,10 +421,15 @@ static int sortabook(const void *a, const void *b)
 
 void ab_listselect_fp(FILE *w)
 {
-FILE	*fp;
-char *header, *value;
-struct	abooklist *a=0, *b, **aa;
-size_t	acnt=0, i;
+	FILE	*fp;
+	char *header, *value;
+	struct	abooklist *a=0, *b, **aa;
+	size_t	acnt=0, i;
+	const struct unicode_info *uiptr
+		=unicode_find(sqwebmail_content_charset);
+
+	if (!uiptr)
+		uiptr=&unicode_ISO8859_1;
 
 	if ((fp=fopen(ADDRESSBOOK, "r")) != 0)
 	{
@@ -426,10 +460,19 @@ size_t	acnt=0, i;
 
 		for (i=0; i<acnt; i++)
 		{
+			char *p;
+
+			p=unicode_xconvert(aa[i]->name,
+					   &unicode_UTF8,
+					   uiptr);
+
 			fprintf(w, "<option value=\"");
-			output_attrencoded_fp(aa[i]->name, w);
+			output_attrencoded_fp(p ? p:aa[i]->name, w);
 			fprintf(w, "\">");
-			output_attrencoded_fp(aa[i]->name, w);
+
+			output_attrencoded_fp(p ? p:aa[i]->name, w);
+			if (p)
+				free(p);
 			fprintf(w, "</option>\n");
 		}
 		free(aa);
@@ -469,14 +512,21 @@ int ab_get_nameaddr( int (*callback_func)(const char *, const char *,
 
 				for (i=0; i<a->naddrs; i++)
 				{
-					char *addr=rfc822_getaddr(a, i);
+					char *addr;
 					char *name;
 
+					if (a->addrs[i].tokens == NULL)
+						continue;
+
+					addr=rfc822_display_addr_tobuf(a, i,
+								       NULL);
 					if (!addr)
 						continue;
 
 					name=a->addrs[i].name ?
-						rfc822_getname(a, i):NULL;
+						rfc822_display_name_tobuf(a, i,
+									  NULL):
+						NULL;
 
 					rc=(*callback_func)(addr, name,
 							    callback_arg);
@@ -535,19 +585,61 @@ static int ab_addrselect_cb(const char *a, const char *n, void *vp)
 	return (0);
 }
 
+static void ab_show_utf8(const char *p,
+			 const struct unicode_info *info)
+{
+	char *p_s=unicode_xconvert(p, &unicode_UTF8, info);
+
+	if (!p_s)
+		return;
+
+	p=p_s;
+
+	while (*p)
+	{
+		size_t i;
+
+		for (i=0; p[i]; ++i)
+		{
+			if (*p == '"' || *p == '\\')
+				break;
+		}
+
+		if (i)
+			call_print_safe_to_stdout(p, i);
+
+		p += i;
+
+		if (*p)
+		{
+			putchar('\\');
+			putchar(*p);
+			++p;
+		}
+	}
+	free(p_s);
+	return;
+}
+
+
 void ab_nameaddr_show(const char *name, const char *addr)
 {
+	const struct unicode_info *info=unicode_find(sqwebmail_content_charset);
+
+	if (!info)
+		return;
+
 	if (name)
 	{
-		char *q=q_escape(name);
 		printf("\"");
-		print_safe(q);
+		ab_show_utf8(name, info);
 		printf("\"&nbsp;");
-		free(q);
 	}
 	printf("&lt;");
+
 	if (addr)
-		print_safe(addr);
+		ab_show_utf8(addr, info);
+
 	printf("&gt;");
 }
 
@@ -622,6 +714,19 @@ char	*edit_name=0;
 char	*edit_addr=0;
 int	replace_index=0;
 
+	const struct unicode_info *uiptr
+		=unicode_find(sqwebmail_content_charset);
+
+	if (!uiptr)
+		uiptr=&unicode_ISO8859_1;
+
+#if 0
+	fp=fopen("/tmp/pid", "w");
+	fprintf(fp, "%d", getpid());
+	fclose(fp);
+	sleep(10);
+#endif
+
 	nick1=cgi("nick");
 	do_edit=0;
 	if (*cgi("nick.edit"))
@@ -682,8 +787,17 @@ int	replace_index=0;
 
 	if (*cgi("nick.delete"))
 	{
+		char *p=unicode_xconvert(cgi("nick"),
+					 uiptr,
+					 &unicode_UTF8);
+
 		do_edit=0;
-		dodelall(cgi("nick"));
+
+		if (p)
+		{
+			dodelall(p);
+			free(p);
+		}
 	}
 	else if (*cgi("add"))
 	{
@@ -696,11 +810,18 @@ int	replace_index=0;
 		{
 			if ((fp=fopen(ADDRESSBOOK, "r")) != 0)
 			{
+				char *editnick_utf8=
+					unicode_xconvert(editnick,
+							 uiptr,
+							 &unicode_UTF8);
+
 				while ((header=maildir_readheader_nolc(fp,
 					&value)) != NULL)
-					if (strcmp(header, editnick) == 0)
+					if (editnick_utf8 &&
+					    strcmp(header, editnick_utf8) == 0)
 						break;
-				if (header)
+
+				if (header && editnick_utf8)
 				{
 				struct rfc822t *t;
 				struct rfc822a *a;
@@ -710,14 +831,32 @@ int	replace_index=0;
 
 					if (a)
 					{
-						dodel(editnick, a,
-							atoi(replacenum),
-							newname,
-							newaddr);
+						char *newname_utf8=
+							unicode_xconvert(newname,
+									 uiptr,
+									 &unicode_UTF8);
+						char *newaddr_utf8=
+							unicode_xconvert(newaddr,
+									 uiptr,
+									 &unicode_UTF8);
+						
+						dodel(editnick_utf8, a,
+						      atoi(replacenum),
+						      newname_utf8 && newaddr_utf8 ?
+						      newname_utf8:NULL,
+						      newname_utf8 && newaddr_utf8 ?
+						      newaddr_utf8:NULL);
 						rfc822a_free(a);
+						if (newname_utf8)
+							free(newname_utf8);
+						if (newaddr_utf8)
+							free(newaddr_utf8);
 					}
 					if (t)	rfc822t_free(t);
 				}
+				if (editnick_utf8)
+					free(editnick_utf8);
+
 				fclose(fp);
 			}
 		}
@@ -754,15 +893,23 @@ int	replace_index=0;
 
 		printf("<table border=\"0\" class=\"nickedit-box\">\n");
 		printf("<tr><td colspan=\"3\">\n");
+
 		printf("%s%s%s", nick_title1, s, nick_title2);
 		printf("</td></tr>\n");
 
 		if ((fp=fopen(ADDRESSBOOK, "r")) != 0)
 		{
+			char *s_utf8=unicode_xconvert(s, uiptr,
+						      &unicode_UTF8);
+
 			while ((header=maildir_readheader_nolc(fp, &value))
 				!= NULL)
-				if (strcmp(header, s) == 0)
+				if (s_utf8 && strcmp(header, s_utf8) == 0)
 					break;
+
+			if (s_utf8)
+				free(s_utf8);
+
 			if (header)
 			{
 			struct rfc822t *t;
@@ -803,56 +950,50 @@ int	replace_index=0;
 							if (edit_name)
 								free(edit_name);
 							edit_name=
-								rfc822_getname(
-									a, i);
+								rfc822_display_name_tobuf(a, i, NULL);
 							if (edit_addr)
 								free(edit_addr);
 							edit_addr=
-								rfc822_getaddr(
-									a, i);
+								rfc822_display_addr_tobuf(a, i, NULL);
 							replace_index=i;
 							break;
 						}
 					}
-				}
-
-				if (a)
-				{
-				int	i;
 
 					for (i=0; i<a->naddrs; i++)
 					{
-					char *s;
+						char *s;
 
 						if (a->addrs[i].tokens == 0)
 							continue;
 						printf("<tr><td align=\"right\""
 						       " class=\"nickname\">");
 
-						s=rfc822_getname(a, i);
-
-						if (s && a->addrs[i].name)
+						if (a->addrs[i].name)
 							/* getname defaults it
 							** here.
 							*/
 						{
-							char *t;
+							char *n=rfc822_display_name_tobuf(a, i, NULL);
 
-							printf("\"");
+							if (n)
+							{
+								printf("\"");
+								ab_show_utf8(n, uiptr);
+								printf("\"");
+								free(n);
+							}
 
-							t=q_escape(s);
-							printf("%s", t);
-							free(t);
-							free(s);
-							printf("\"");
 						}
+
 						printf("</td><td align=\"left\""
 						       " class=\"nickaddr\">"
 						       "&lt;");
-						s=rfc822_getaddr(a, i);
+						s=rfc822_display_addr_tobuf(a, i, NULL);
+
 						if (s)
 						{
-							output_attrencoded(s);
+							ab_show_utf8(s, uiptr);
 							free(s);
 						}
 						printf("&gt;</td><td><input type=\"submit\" name=\"startedit%d\" value=\"%s\" />&nbsp;<input type=\"submit\" name=\"del%d\" value=\"%s\" /></td></tr>\n",
@@ -871,18 +1012,34 @@ int	replace_index=0;
 
 		if (edit_name)
 		{
-			printf(" value=\"");
-			output_attrencoded(edit_name);
-			printf("\"");
+			char *edit_name_native=
+				unicode_xconvert(edit_name,
+						 &unicode_UTF8,
+						 uiptr);
+
+			if (edit_name_native)
+			{
+				printf(" value=\"");
+				output_attrencoded(edit_name_native);
+				printf("\"");
+				free(edit_name_native);
+			}
 		}
 		printf(" /></td></tr>\n");
 
 		printf("<tr><td align=\"right\">%s</td><td><input type=\"text\" name=\"newaddress\" class=\"nicknewaddr\"", nick_address);
 		if (edit_addr)
 		{
-			printf(" value=\"");
-			output_attrencoded(edit_addr);
-			printf("\"");
+			char *edit_addr_native=
+				unicode_xconvert(edit_addr,
+						 &unicode_UTF8,
+						 uiptr);
+			if (edit_addr_native)
+			{
+				printf(" value=\"");
+				output_attrencoded(edit_addr_native);
+				printf("\"");
+			}
 		}
 
 		printf(" /></td><td>");
