@@ -1,11 +1,11 @@
 /*
-** Copyright 1998 - 2006 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2009 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
 
 /*
-** $Id: attachments.c,v 1.48 2008/07/20 03:15:08 mrsam Exp $
+** $Id: attachments.c,v 1.49 2009/11/08 18:14:47 mrsam Exp $
 */
 #include	"config.h"
 #include	"sqwebmail.h"
@@ -195,14 +195,19 @@ const struct unicode_info *uiptr=unicode_find(sqwebmail_content_charset);
 		    rfc2231_udecodeDisposition(q, "filename", uiptr,
 					       &content_name) < 0)
 			content_name=NULL;
+
 		if (!content_name &&
 		    ((cn=rfc2045_getattr(q->content_type_attr, "name")) ||
 		     (cn=rfc2045_getattr(q->content_disposition_attr,
-					 "filename"))) &&
-		    strstr(cn, "=?") && strstr(cn, "?="))
-		    /* RFC2047 header encoding (not compliant to RFC2047) */
-			content_name = rfc2047_decode_unicode(cn, uiptr,
-				RFC2047_DECODE_ABORT);
+					 "filename"))))
+		{
+			content_name =
+				rfc822_display_hdrvalue_tobuf("subject",
+							      cn,
+							      uiptr->chset,
+							      NULL,
+							      NULL);
+		}
 
 		if ((!content_name || !*content_name) &&
 		    strcmp(content_type, "application/pgp-keys") == 0)
