@@ -1,11 +1,11 @@
 /*
-** Copyright 1998 - 2007 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2009 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
 
 /*
-** $Id: folder.c,v 1.185 2009/06/27 16:32:38 mrsam Exp $
+** $Id: folder.c,v 1.188 2009/11/18 03:38:50 mrsam Exp $
 */
 #include	"config.h"
 #include	<stdio.h>
@@ -1414,12 +1414,6 @@ static void init_smileys(struct msg2html_info *info)
 
 static void email_address_start(const char *name, const char *addr)
 {
-	const struct unicode_info *uiptr=
-		unicode_find(sqwebmail_content_charset);
-
-	if (!uiptr)
-		uiptr=&unicode_ISO8859_1;
-
 	if (is_preview_mode())
 	    return;
 
@@ -1429,15 +1423,8 @@ static void email_address_start(const char *name, const char *addr)
 	       cgi("pos"));
 
 	if (name)
-	{
-		char *v=rfc2047_decode_unicode(name, uiptr,
-					       RFC2047_DECODE_REPLACE);
-		if (v)
-		{
-			output_urlencoded(v);
-			free(v);
-		}
-	}
+		output_urlencoded(name);
+
 	printf("&amp;newaddr=");
 	if (addr)
 		output_urlencoded(addr);
@@ -3434,22 +3421,18 @@ static char *truncate_at(const char *str,
 			 const struct unicode_info *uiptr,
 			 size_t ncols)
 {
-	char *uibuf=rfc2047_decode_unicode(str, &unicode_UTF8,
-					   RFC2047_DECODE_DISCARD);
 	unicode_char *uc;
 	size_t n;
 	size_t cols, tp=0;
+	char *retbuf;
 
-	if (!uibuf)
+	if (!str)
 		return NULL;
 
-	uc= (*unicode_UTF8.c2u)(&unicode_UTF8, uibuf, NULL);
+	uc= (*unicode_UTF8.c2u)(&unicode_UTF8, str, NULL);
 
 	if (!uc)
-	{
-		free(uibuf);
 		return NULL;
-	}
 
 	for (cols=0, n=0; uc[n]; n++) {
 
@@ -3469,12 +3452,8 @@ static char *truncate_at(const char *str,
 		uc[tp+3]=0;
 	}
 
-
-	free(uibuf);
-
-	uibuf=(*uiptr->u2c)(uiptr, uc, NULL);
+	retbuf=(*uiptr->u2c)(uiptr, uc, NULL);
 
 	free(uc);
-	return uibuf;
+	return retbuf;
 }
-
