@@ -5,7 +5,7 @@
 
 
 /*
-** $Id: gpg.c,v 1.13 2006/05/28 15:29:52 mrsam Exp $
+** $Id: gpg.c,v 1.14 2008/07/20 03:15:08 mrsam Exp $
 */
 #include	"sqwebmail.h"
 #include	"config.h"
@@ -39,7 +39,6 @@ extern void print_attrencodedlen(const char *, size_t, int, FILE *);
 extern void print_safe(const char *);
 const char *sqwebmail_content_charset;
 
-#if HAVE_SQWEBMAIL_UNICODE
 
 static char gpgerrbuf[1024];
 static size_t gpgerrcnt=0;
@@ -753,44 +752,3 @@ int gpgexportkey(const char *fingerprint, int issecret,
 				      arg));
 }
 
-#else
-void gpglistpub()
-{
-}
-
-void gpglistsec()
-{
-}
-
-void gpgcreate()
-{
-}
-
-void gpgdo()
-{
-}
-
-void sent_gpgerrtxt()
-{
-}
-
-void sent_gpgerrresume()
-{
-}
-
-void gpgselectpubkey()
-{
-}
-
-void gpgselectprivkey()
-{
-}
-
-int gpgexportkey(const char *fingerprint, int issecret,
-		 int (*func)(const char *, size_t, void *),
-		 void *arg)
-{
-	return (1);
-}
-
-#endif
