@@ -1,11 +1,11 @@
 /*
-** Copyright 1998 - 2007 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2009 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
 
 /*
-** $Id: html.c,v 1.28 2007/05/20 00:04:55 mrsam Exp $
+** $Id: html.c,v 1.29 2009/02/04 23:53:32 mrsam Exp $
 */
 #include	<stdio.h>
 #include	<ctype.h>
@@ -154,6 +154,11 @@ char *p;
 				tai->tagvalue=0;
 				tai->tagvaluelen=0;
 			}
+			while (*p && isspace((int)(unsigned char)*p))	p++;
+			if (*p == '=')
+				memset(info->tagbuf, ' ',
+				       strlen(info->tagbuf));
+
 		}
 		else
 		{
@@ -499,10 +504,15 @@ static char *redirectencode(const char *, size_t );
 
 static void replacelink(struct htmlfilter_info *info, size_t l, const char *p)
 {
-struct tagattrinfo *tagattrp=info->tagattr+l;
-char	*newbuf;
-size_t	plen=tagattrp->tagvalue - info->tagbuf;
-size_t	i;
+	struct tagattrinfo *tagattrp=info->tagattr+l;
+	char	*newbuf;
+	size_t	plen;
+	size_t	i;
+
+	if (!tagattrp->tagvalue)
+		return;
+
+	plen=tagattrp->tagvalue - info->tagbuf;
 
 	newbuf=malloc(strlen(info->tagbuf)+strlen(p)+1);
 			/* Yes, that's a bit too much.  That's OK */
