@@ -1,11 +1,11 @@
 /*
-** Copyright 1998 - 2009 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2010 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
 
 /*
-** $Id: maildir.c,v 1.89 2009/06/12 11:09:50 mrsam Exp $
+** $Id: maildir.c,v 1.94 2010/03/19 01:09:26 mrsam Exp $
 */
 #include	"config.h"
 #include	<stdio.h>
@@ -799,7 +799,7 @@ char *filename=maildir_find(folder, msgid);
 
 				if (filesize > 0)
 					maildir_quota_deleted(".",
-							      -(off_t)filesize,
+							      -(int64_t)filesize,
 							      -1);
 			}
 			free(d);
@@ -890,7 +890,7 @@ static int do_msgmove(const char *from,
 		{
 
 			if (!from_shared)
-				maildir_quota_deleted(".", -(off_t)filesize, -1);
+				maildir_quota_deleted(".", -(int64_t)filesize, -1);
 		}
 		else if (!dest_shared && maildirquota_countfolder(destdir) &&
 			 (from_shared || !maildirquota_countfolder(fromdir))
@@ -1214,7 +1214,7 @@ static void maildir_checknew(const char *folder, const char *dir)
 
 				if (filesize > 0)
 					maildir_quota_deleted(".",
-							      -(off_t)filesize,
+							      -(int64_t)filesize,
 							      -1);
 			}
 
@@ -1425,7 +1425,7 @@ void maildir_autopurge()
 
 				if (filesize > 0)
 					maildir_quota_deleted(".",
-							      -(off_t)filesize,
+							      -(int64_t)filesize,
 							      -1);
 			}
 
@@ -1481,8 +1481,17 @@ static int subjectcmp(const char *a, const char *b)
 	char	*as;
 	char	*bs;
 
-	as=rfc2047_decode_unicode(a, &unicode_UTF8, 0);
-	bs=rfc2047_decode_unicode(b, &unicode_UTF8, 0);
+	as=rfc822_display_hdrvalue_tobuf("subject", a, unicode_UTF8.chset,
+					 NULL, NULL);
+
+	if (!as)
+		as=strdup(a);
+
+	bs=rfc822_display_hdrvalue_tobuf("subject", b, unicode_UTF8.chset,
+					 NULL, NULL);
+
+	if (!bs)
+		bs=strdup(b);
 
 	if (as)
 	{
@@ -2051,9 +2060,15 @@ int	fd;
 	{
 		if (strcmp(hdr, "subject") == 0)
 		{
+			char *uibuf=rfc822_display_hdrvalue_tobuf("subject",
+								  val,
+								  unicode_UTF8
+								  .chset,
+								  NULL, NULL);
+
 			if (mi->subject_s)	free(mi->subject_s);
 
-			mi->subject_s=strdup(val);
+			mi->subject_s=uibuf;
 			if (!mi->subject_s)	enomem();
 		}
 
@@ -2073,30 +2088,45 @@ int	fd;
 			strcmp(hdr, "to") == 0 || strcmp(hdr, "cc") == 0:
 			strcmp(hdr, "from") == 0) && fromheader == 0)
 		{
-		struct rfc822t *from_addr;
-		struct rfc822a *from_addra;
-		char	*p;
-		int dotflag=0;
+			struct rfc822t *from_addr;
+			struct rfc822a *from_addra;
+			char	*p;
+			int dotflag=0;
+			int cnt;
 
 			from_addr=rfc822t_alloc_new(val, NULL, NULL);
 			if (!from_addr)	enomem();
 			from_addra=rfc822a_alloc(from_addr);
 			if (!from_addra)	enomem();
 
-			if (from_addra->naddrs > 1)
-				dotflag=1;
+			p=NULL;
 
-			if (from_addra->naddrs > 0)
-				p=rfc822_getname(from_addra, 0);
-			else
-				p=val;
+			for (cnt=0; cnt<from_addra->naddrs; ++cnt)
+			{
+				if (from_addra->addrs[cnt].tokens == NULL)
+					continue;
 
-			if (fromheader)	free(fromheader);
-			if ((fromheader=malloc(strlen(p)+7)) == 0)
-				enomem();
-			strcpy(fromheader, p);
-			if (dotflag)
-				strcat(fromheader, "...");
+				if (p)
+				{
+					dotflag=1;
+					break;
+				}
+
+				p=rfc822_display_name_tobuf(from_addra, cnt,
+							    unicode_UTF8.chset);
+			}
+
+			if (p)
+			{
+				if (fromheader)	free(fromheader);
+				if ((fromheader=malloc(strlen(p)+7)) == 0)
+					enomem();
+				strcpy(fromheader, p);
+				if (dotflag)
+					strcat(fromheader, "...");
+
+				free(p);
+			}
 
 			rfc822a_free(from_addra);
 			rfc822t_free(from_addr);
@@ -2895,7 +2925,7 @@ int	maildir_closemsg(int n,	/* File descriptor */
 			{
 				if (isok < 0) /* Force it */
 				{
-					maildir_quota_deleted(".", (off_t)
+					maildir_quota_deleted(".", (int64_t)
 							      (stat_buf.st_size
 							       -prevsize),
 							      prevsize == 0
@@ -2910,7 +2940,7 @@ int	maildir_closemsg(int n,	/* File descriptor */
 		}
 		else if (prevsize != stat_buf.st_size)
 		{
-			maildir_quota_deleted(".", (off_t)
+			maildir_quota_deleted(".", (int64_t)
 					      (stat_buf.st_size-prevsize),
 					      prevsize == 0 ? 1:0);
 		}
