@@ -1,10 +1,10 @@
 /*
-** Copyright 2007 Double Precision, Inc.  See COPYING for
+** Copyright 2007-2009 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
 /*
-** $Id: msg2html.c,v 1.7 2008/07/20 03:15:08 mrsam Exp $
+** $Id: msg2html.c,v 1.9 2009/11/18 03:38:50 mrsam Exp $
 */
 
 #include "msg2html.h"
@@ -240,10 +240,17 @@ static void showaddressheader_printc(char c, void *p)
 		char *name=0;
 		char *addr=0;
 
-		if (sai->curindex < sai->a->naddrs)
+		if (sai->curindex < sai->a->naddrs &&
+		    sai->a->addrs[sai->curindex].tokens)
 		{
-			name=rfc822_getname(sai->a, sai->curindex);
-			addr=rfc822_getaddr(sai->a, sai->curindex);
+			name=rfc822_display_name_tobuf(sai->a,
+						       sai->curindex,
+						       sai->info->
+						       output_character_set);
+			addr=rfc822_display_addr_tobuf(sai->a,
+						       sai->curindex,
+						       sai->info->
+						       output_character_set);
 		}
 
 		if (sai->info->email_address_start)
@@ -308,10 +315,9 @@ static void showmsgrfc822_addressheader(struct msg2html_info *info,
 	sai.curindex=0;
 	sai.isfirstchar=1;
 
-
-	rfc2047_print_unicode(rfca, info->output_character_set,
-			      showaddressheader_printc,
-			      showaddressheader_printsep, &sai);
+	rfc2047_print_unicodeaddr(rfca, info->output_character_set,
+				  showaddressheader_printc,
+				  showaddressheader_printsep, &sai);
 	if (!sai.isfirstchar)
 		showaddressheader_printsep("", &sai);
 	/* This closes the final </a> */
@@ -497,8 +503,15 @@ const struct unicode_info *uiptr=unicode_find(info->output_character_set);
 		{
 			if (save_subject)	free(save_subject);
 
-			save_subject=rfc2047_decode_unicode(value, uiptr,
-				RFC2047_DECODE_REPLACE);
+			save_subject=
+				rfc822_display_hdrvalue_tobuf(header, value,
+							      uiptr->chset,
+							      NULL,
+							      NULL);
+
+			if (!save_subject)
+				save_subject=strdup(value);
+
 			free(header);
 			continue;
 		}
@@ -637,8 +650,12 @@ const struct unicode_info *uiptr=unicode_find(info->output_character_set);
 				 "filename"))) &&
 	    strstr(cn, "=?") && strstr(cn, "?="))
 	    /* RFC2047 header encoding (not compliant to RFC2047) */
-		content_name = rfc2047_decode_unicode(cn, uiptr,
-			RFC2047_DECODE_ABORT);
+	{
+		content_name = rfc822_display_hdrvalue_tobuf("subject",
+							     cn,
+							     uiptr->chset,
+							     NULL, NULL);
+	}
 
 	rfc2045_mimepos(rfc, &start_pos, &end_pos, &start_body,
 			&dummy2, &dummy2);
