@@ -1,11 +1,11 @@
 /*
-** Copyright 1998 - 2006 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2009 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
 
 /*
-** $Id: newmsg.c,v 1.67 2008/07/20 03:15:08 mrsam Exp $
+** $Id: newmsg.c,v 1.69 2009/11/14 21:15:43 mrsam Exp $
 */
 #include	"config.h"
 #include	"sqwebmail.h"
@@ -86,10 +86,17 @@ const struct unicode_info *uiptr=unicode_find(sqwebmail_content_charset);
 		field, hdrmaxlen);
 	if (encoded)
 	{
-	char	*s;
+		char	*s;
+
+		s=rfc822_display_hdrvalue_tobuf("subject",
+						encoded,
+						uiptr->chset,
+						NULL,
+						NULL);
+
+		if (!s)
+			s=strdup(encoded);
 
-		s=rfc2047_decode_unicode(encoded, uiptr,
-			RFC2047_DECODE_NOTAG|RFC2047_DECODE_REPLACE);
 		if (!s)	enomem();
 		output_attrencoded(s);
 		free(s);
@@ -138,9 +145,9 @@ const char	*p=getarg("HDRMAXLEN");
 
 		if (a)
 		{
-			rfc2047_print_unicode(a, sqwebmail_content_charset,
-					      printc,
-					      printsep, NULL);
+			rfc2047_print_unicodeaddr(a, sqwebmail_content_charset,
+						  printc,
+						  printsep, NULL);
 			rfc822a_free(a);
 		}
 
@@ -515,6 +522,9 @@ void newmsg_init(const char *folder, const char *pos)
 				continue;
 			}
 
+			while (*value && isspace(*value))
+				++value;
+
 			if (strcmp(header, "from") == 0)
 				rfchp= &curfrom;
 			if (strcmp(header, "reply-to") == 0)
@@ -571,6 +581,17 @@ void newmsg_init(const char *folder, const char *pos)
 	printf("</td></tr></table>");
 
 	printf("</td></tr>\n");
+
+#if 0
+			{
+				FILE *fp;
+				fp=fopen("/tmp/pid", "w");
+				fprintf(fp, "%d", getpid());
+				fclose(fp);
+				sleep(10);
+			}
+#endif
+
 	newmsg_header_rfc822(tolab, "headerto", curto, cgi("to"), 0);
 	newmsg_header_rfc822(cclab, "headercc", curcc, cgi("cc"), 0);
 	newmsg_header_rfc822(bcclab, "headerbcc", curbcc, cgi("bcc"), 0);
