@@ -1,5 +1,5 @@
 /*
-** $Id: newmsg.h,v 1.7 2001/12/07 12:54:59 mrsam Exp $
+** $Id: newmsg.h,v 1.8 2007/05/06 21:49:29 mrsam Exp $
 */
 #ifndef	newmsg_h
 #define	newmsg_h
@@ -20,9 +20,6 @@
 
 extern void newmsg_init(const char *, const char *);
 extern void newmsg_do(const char *);
-extern void preview_start();
-extern int preview_callback(const char *, size_t, void *);
-extern void preview_end();
 
 extern char *newmsg_createdraft_do(const char *, const char *, int);
 #define NEWMSG_SQISPELL	1
