@@ -1,11 +1,11 @@
 /*
-** Copyright 1998 - 2007 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2009 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
 
 /*
-** $Id: newmsg_create.c,v 1.64 2008/07/20 17:00:33 mrsam Exp $
+** $Id: newmsg_create.c,v 1.66 2009/11/14 21:15:43 mrsam Exp $
 */
 #include	"config.h"
 #include	"cgi/cgi.h"
@@ -80,7 +80,7 @@ static void create_draftheader_do(const char *hdrname, const char *p,
 	int isrfc822addr);
 
 static void create_draftheader(const char *hdrname, const char *p,
-	const char *q, int isrfc822addr)
+			       const char *q, int isrfc822addr)
 {
 	if (q && *q)	/* Add from address book */
 	{
@@ -189,25 +189,8 @@ size_t	l;
 	}
 	else
 	{
-	struct rfc822t *t;
-	struct rfc822a *a;
-
-		/*
-		** For proper RFC 2047 encoding, we must RFC822-parse
-		** this header.
-		*/
-
-		s=0;
-		if ((t=rfc822t_alloc_new(p, NULL, NULL)) != 0)
-		{
-			if ((a=rfc822a_alloc(t)) != 0)
-			{
-				s=rfc2047_encode_header(a,
-					sqwebmail_content_charset);
-				rfc822a_free(a);
-			}
-			rfc822t_free(t);
-		}
+		s=rfc2047_encode_header_tobuf("to", p,
+					      sqwebmail_content_charset);
 	}
 
 	header_wrap(hdrname, s, NULL, &l);
@@ -414,6 +397,16 @@ char *buf;
 */
 		if (!is_newevent)
 		{
+#if 0
+			{
+				FILE *fp;
+				fp=fopen("/tmp/pid", "w");
+				fprintf(fp, "%d", getpid());
+				fclose(fp);
+				sleep(10);
+			}
+#endif
+
 			create_draftheader("To: ", cgi("headerto"),
 					   cgi("addressbook_to"), 1);
 			create_draftheader("Cc: ", cgi("headercc"),
@@ -726,12 +719,12 @@ struct lookup_buffers {
 static int lookup_addressbook_do(const char *header, const char *value,
 	struct lookup_buffers **lookup_buffer_list)
 {
-struct	rfc822t *t;
-struct	rfc822a *a;
-int	i;
-char	*newbuf;
-struct lookup_buffers *ptr;
-int	expanded=0;
+	struct	rfc822t *t;
+	struct	rfc822a *a;
+	int	i;
+	char	*newbuf;
+	struct lookup_buffers *ptr;
+	int	expanded=0;
 
 	t=rfc822t_alloc_new(value, NULL, NULL);
 	if (!t)	enomem();
@@ -744,9 +737,10 @@ int	expanded=0;
 
 	for (i=0; i<a->naddrs; i++)
 	{
-	char	*p;
-	const	char *q;
-	struct lookup_buffers *r;
+		char	*p;
+		char	*s;
+		const	char *q;
+		struct lookup_buffers *r;
 
 		if (a->addrs[i].tokens == 0)
 			continue;
@@ -778,11 +772,16 @@ int	expanded=0;
 			continue;
 		}
 
-		if ((q=ab_find(p)) == 0)
+		s=rfc822_display_addr_str_tobuf(p, unicode_UTF8.chset);
+
+		if (s == NULL || (q=ab_find(s)) == 0)
 		{
+			if (s)
+				free(s);
 			free(p);
 			continue;
 		}
+		free(s);
 
 		r=malloc(sizeof(struct lookup_buffers));
 		if (r)	r->buf=r->buf2=0;
@@ -826,15 +825,29 @@ int	expanded=0;
 
 static void lookup_addressbook(const char *header, const char *value)
 {
-struct lookup_buffers *lookup_buffer_list=0;
-int	rc;
-const struct unicode_info *uiptr=unicode_find(sqwebmail_content_charset);
-char	*s=rfc2047_decode_unicode(value, uiptr,
-				  RFC2047_DECODE_NOTAG|RFC2047_DECODE_REPLACE);
+	struct lookup_buffers *lookup_buffer_list=0;
+	int	rc;
+	char *header_cpy;
+	char *value_cpy;
+	/*
+	** header & value may be pointing to buffer allocated by
+	** maildir_readheader.
+	** lookup_addressbook_do may call it again.
+	*/
 
-	if (!s)	enomem();
-	rc=lookup_addressbook_do(header, s, &lookup_buffer_list);
-	free(s);
+	header_cpy=strdup(header);
+	if (!header_cpy)
+		enomem();
+
+	value_cpy=strdup(value);
+	if (!value_cpy)
+	{
+		free(header_cpy);
+		enomem();
+	}
+
+	rc=lookup_addressbook_do(header_cpy, value_cpy, &lookup_buffer_list);
+	free(header_cpy);
 
 	while (lookup_buffer_list)
 	{
