@@ -1,11 +1,11 @@
 /*
-** Copyright 2001-2006 Double Precision, Inc.  See COPYING for
+** Copyright 2001-2010 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
 
 /*
-** $Id: pcp.c,v 1.30 2006/05/28 15:29:52 mrsam Exp $
+** $Id: pcp.c,v 1.32 2010/03/19 01:09:26 mrsam Exp $
 */
 #include	"sqwebmail.h"
 #include	"pcp.h"
@@ -915,8 +915,16 @@ void sqpcp_eventstart()
 			rfc822hdr_collapse(&h);
 			if (from_buf)
 				free(from_buf);
-			from_buf=rfc2047_decode_enhanced
-				(h.value, sqwebmail_content_charset);
+
+			from_buf=NULL;
+
+			if ((from_buf=
+			     rfc822_display_hdrvalue_tobuf(h.header,
+							   h.value,
+							   sqwebmail_content_charset,
+							   NULL, NULL)) == NULL)
+				from_buf=strdup(h.value);
+
 			if (from_buf)
 				cgi_put("from", from_buf);
 		}
@@ -925,8 +933,14 @@ void sqpcp_eventstart()
 			rfc822hdr_collapse(&h);
 			if (subj_buf)
 				free(subj_buf);
-			subj_buf=rfc2047_decode_enhanced
-				(h.value, sqwebmail_content_charset);
+
+			subj_buf=rfc822_display_hdrvalue_tobuf(h.header,
+							       h.value,
+							       sqwebmail_content_charset,
+							       NULL, NULL);
+			if (!subj_buf)
+				subj_buf=strdup(subj_buf);
+
 			if (subj_buf)
 				cgi_put("headersubject", subj_buf);
 		}
@@ -1335,8 +1349,14 @@ static void print_event_subject(char *flags, const char *subject, unsigned w)
 		printf("%s", getarg(p));
 	}
 
-	p=rfc2047_decode_enhanced(subject ? subject:"",
-				  sqwebmail_content_charset);
+	p=rfc822_display_hdrvalue_tobuf("subject",
+					subject ? subject:"",
+					sqwebmail_content_charset,
+					NULL,
+					NULL);
+
+	if (!p)
+		p=strdup(subject ? subject:"");
 
 	if (!p)
 		return;
@@ -2379,7 +2399,7 @@ static void dropquota(const char *filename, int fd)
 		filesize=stat_buf.st_size;
 	}
 
-	maildir_quota_deleted(".", -filesize, -1);
+	maildir_quota_deleted(".", (int64_t)-filesize, -1);
 }
 
 /* ------------------------------------------------------------------------
