@@ -1,11 +1,11 @@
 /*
-** Copyright 1998 - 2008 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2009 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
 
 /*
-** $Id: sqwebmail.c,v 1.146 2009/02/04 23:53:32 mrsam Exp $
+** $Id: sqwebmail.c,v 1.147 2009/11/08 18:14:47 mrsam Exp $
 */
 #include	"sqwebmail.h"
 #include	"sqconfig.h"
@@ -124,6 +124,8 @@ const char *sqwebmail_sessiontoken=0;
 const char *sqwebmail_content_language=0;
 const char *sqwebmail_content_locale;
 const char *sqwebmail_system_charset=0;
+static char *sys_locale_charset=0;
+
 const char *sqwebmail_content_ispelldict;
 const char *sqwebmail_content_charset;
 
@@ -1965,6 +1967,9 @@ void cleanup()
 	sqwebmail_content_language=0;
 	sqwebmail_content_locale=0;
 	sqwebmail_system_charset=0;
+	if (sys_locale_charset)
+		free(sys_locale_charset);
+	sys_locale_charset=0;
 	sqwebmail_content_ispelldict=0;
 	folder_cleanup();
 	maildir_cleanup();
@@ -2037,7 +2042,7 @@ char	*cl=http11_best_content_language(templatedir,
 	sqwebmail_system_charset = locale_charset();
 #elif	HAVE_LANGINFO_CODESET
 	setlocale(LC_CTYPE, sqwebmail_content_locale);
-	sqwebmail_system_charset = nl_langinfo(CODESET);
+	sqwebmail_system_charset = sys_locale_charset=strdup(nl_langinfo(CODESET));
 #else
 	sqwebmail_system_charset = NULL;
 #endif	/* USE_LIBCHARSET */
@@ -2409,7 +2414,8 @@ time_t	timeouthard=get_timeouthard();
 		sqwebmail_system_charset = locale_charset();
 #elif	HAVE_LANGINFO_CODESET
 		setlocale(LC_CTYPE, sqwebmail_content_locale);
-		sqwebmail_system_charset = nl_langinfo(CODESET);
+		sqwebmail_system_charset = sys_locale_charset
+			= strdup(nl_langinfo(CODESET));
 #else
 		sqwebmail_system_charset = NULL;
 #endif  /* USE_LIBCHARSET */
@@ -2545,7 +2551,9 @@ time_t	timeouthard=get_timeouthard();
 				sqwebmail_system_charset = locale_charset();
 #elif	HAVE_LANGINFO_CODESET
 				setlocale(LC_CTYPE, sqwebmail_content_locale);
-				sqwebmail_system_charset = nl_langinfo(CODESET);
+
+				sqwebmail_system_charset = sys_locale_charset
+					= strdup(nl_langinfo(CODESET));
 #else
 				sqwebmail_system_charset = NULL;
 #endif	/* USE_LIBCHARSET */
